@@ -47,7 +47,7 @@ class PythonParserTest(PythonParserTestBase):
                 pass
             """)
         assert parser.exit_counts() == {
-            2:1, 3:1, 4:2, 5:1, 7:1, 9:1, 10:1
+            2:1, 3:1, 4:2, 5:1, 7:1, 9:1, 10:1,
         }
 
     def test_generator_exit_counts(self) -> None:
@@ -79,7 +79,7 @@ class PythonParserTest(PythonParserTestBase):
             b = 9
             """)
         assert parser.exit_counts() == {
-            1: 1, 2:1, 3:2, 4:1, 5:2, 6:1, 7:1, 8:1, 9:1
+            1: 1, 2:1, 3:2, 4:1, 5:2, 6:1, 7:1, 8:1, 9:1,
         }
 
     def test_excluded_classes(self) -> None:
@@ -93,7 +93,7 @@ class PythonParserTest(PythonParserTestBase):
                     pass
             """)
         assert parser.exit_counts() == {
-            1:0, 2:1, 3:1
+            1:0, 2:1, 3:1,
         }
 
     def test_missing_branch_to_excluded_code(self) -> None:
@@ -425,6 +425,24 @@ class ExclusionParserTest(PythonParserTestBase):
         )
         assert parser.statements == {1,7}
 
+    def test_multiline_if_no_branch(self) -> None:
+        # From https://github.com/nedbat/coveragepy/issues/754
+        parser = self.parse_text("""\
+            if (this_is_a_verylong_boolean_expression == True   # pragma: no branch
+                and another_long_expression and here_another_expression):
+                do_something()
+            """,
+        )
+        parser2 = self.parse_text("""\
+            if this_is_a_verylong_boolean_expression == True and another_long_expression \\
+                and here_another_expression:  # pragma: no branch
+                do_something()
+            """,
+        )
+        assert parser.statements == parser2.statements == {1, 3}
+        pragma_re = ".*pragma: no branch.*"
+        assert parser.lines_matching(pragma_re) == parser2.lines_matching(pragma_re)
+
     def test_excluding_function(self) -> None:
         parser = self.parse_text("""\
             def fn(foo):      # nocover
@@ -759,7 +777,7 @@ class ParserMissingArcDescriptionTest(PythonParserTestBase):
             """)
         expected = "line 1 didn't jump to line 2, because the condition on line 1 was never true"
         assert expected == parser.missing_arc_description(1, 2)
-        expected = "line 1 didn't jump to line 3, because the condition on line 1 was never false"
+        expected = "line 1 didn't jump to line 3, because the condition on line 1 was always true"
         assert expected == parser.missing_arc_description(1, 3)
         expected = (
             "line 6 didn't return from function 'func5', " +
@@ -772,7 +790,7 @@ class ParserMissingArcDescriptionTest(PythonParserTestBase):
         assert expected == parser.missing_arc_description(11, 12)
         expected = (
             "line 11 didn't jump to line 13, " +
-            "because the condition on line 11 was never false"
+            "because the condition on line 11 was always true"
         )
         assert expected == parser.missing_arc_description(11, 13)
 
@@ -902,21 +920,23 @@ class ParserMissingArcDescriptionTest(PythonParserTestBase):
         assert parser.missing_arc_description(2, -3) == "line 3 didn't finish the lambda on line 3"
 
     @pytest.mark.skipif(not env.PYBEHAVIOR.match_case, reason="Match-case is new in 3.10")
-    def test_match_case_with_default(self) -> None:
+    def test_match_case(self) -> None:
         parser = self.parse_text("""\
-            for command in ["huh", "go home", "go n"]:
-                match command.split():
-                    case ["go", direction] if direction in "nesw":
-                        match = f"go: {direction}"
-                    case ["go", _]:
-                        match = "no go"
-                print(match)
+            match command.split():
+                case ["go", direction] if direction in "nesw":      # 2
+                    match = f"go: {direction}"
+                case ["go", _]:                                     # 4
+                    match = "no go"
+            print(match)                                            # 6
             """)
-        assert parser.missing_arc_description(3, 4) == (
-            "line 3 didn't jump to line 4, because the pattern on line 3 never matched"
+        assert parser.missing_arc_description(2, 3) == (
+            "line 2 didn't jump to line 3, because the pattern on line 2 never matched"
         )
-        assert parser.missing_arc_description(3, 5) == (
-            "line 3 didn't jump to line 5, because the pattern on line 3 always matched"
+        assert parser.missing_arc_description(2, 4) == (
+            "line 2 didn't jump to line 4, because the pattern on line 2 always matched"
+        )
+        assert parser.missing_arc_description(4, 6) == (
+            "line 4 didn't jump to line 6, because the pattern on line 4 always matched"
         )
 
 
